@@ -43,6 +43,7 @@ __all__ = (
     "SchemaStatusType",
     "TypeDefinitionFormatType",
     "ServiceName",
+    "PaginatorName",
 )
 
 
@@ -72,7 +73,13 @@ AuthorizationTypeType = Literal["AWS_IAM"]
 ConflictDetectionTypeType = Literal["NONE", "VERSION"]
 ConflictHandlerTypeType = Literal["AUTOMERGE", "LAMBDA", "NONE", "OPTIMISTIC_CONCURRENCY"]
 DataSourceTypeType = Literal[
-    "AMAZON_DYNAMODB", "AMAZON_ELASTICSEARCH", "AWS_LAMBDA", "HTTP", "NONE", "RELATIONAL_DATABASE"
+    "AMAZON_DYNAMODB",
+    "AMAZON_ELASTICSEARCH",
+    "AMAZON_OPENSEARCH_SERVICE",
+    "AWS_LAMBDA",
+    "HTTP",
+    "NONE",
+    "RELATIONAL_DATABASE",
 ]
 DefaultActionType = Literal["ALLOW", "DENY"]
 FieldLogLevelType = Literal["ALL", "ERROR", "NONE"]
@@ -371,3 +378,12 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal[
+    "list_api_keys",
+    "list_data_sources",
+    "list_functions",
+    "list_graphql_apis",
+    "list_resolvers",
+    "list_resolvers_by_function",
+    "list_types",
+]
